diff --git a/application/config/navigation.php b/application/config/navigation.php
index b788dc40c..d76b8a7f2 100644
--- a/application/config/navigation.php
+++ b/application/config/navigation.php
@@ -27,7 +27,7 @@ $config['navigation_header'] = array(
'oehbeitragsverwaltung' => array(
'link' => site_url('codex/Oehbeitrag'),
'icon' => '',
- 'description' => 'Öhbeitragsverwaltung',
+ 'description' => 'ÖH-Beitragsverwaltung',
'expand' => true,
'sort' => 20,
'requiredPermissions' => 'admin:w'
@@ -102,6 +102,13 @@ $config['navigation_header'] = array(
'description' => 'BPK Wartung',
'sort' => 20,
'requiredPermissions' => 'admin:r'
+ ),
+ 'errormonitoring' => array(
+ 'link' => site_url('system/issues/Issues'),
+ 'description' => 'Fehler Monitoring',
+ 'expand' => true,
+ 'sort' => 30,
+ 'requiredPermissions' => 'system/issues_verwalten:r'
)
)
),
@@ -133,13 +140,6 @@ $config['navigation_header'] = array(
'expand' => true,
'sort' => 20,
'requiredPermissions' => 'system/developer:r'
- ),
- 'errormonitoring' => array(
- 'link' => site_url('system/issues/Issues'),
- 'description' => 'Fehler Monitoring',
- 'expand' => true,
- 'sort' => 20,
- 'requiredPermissions' => 'system/issues_verwalten:r'
)
)
)
diff --git a/application/controllers/codex/Oehbeitrag.php b/application/controllers/codex/Oehbeitrag.php
index fa27d1ebb..da8c63e08 100644
--- a/application/controllers/codex/Oehbeitrag.php
+++ b/application/controllers/codex/Oehbeitrag.php
@@ -4,7 +4,7 @@ if (! defined("BASEPATH")) exit("No direct script access allowed");
class Oehbeitrag extends Auth_Controller
{
- const STUDIENSEMESTER_START = 'WS2020';
+ const STUDIENSEMESTER_START = 'WS2020'; // Öhbeitrage can be assigned beginning with this Studiensemester
public function __construct()
{
@@ -23,6 +23,14 @@ class Oehbeitrag extends Auth_Controller
$this->load->model('organisation/Studiensemester_model', 'StudiensemesterModel');
$this->load->library('WidgetLib');
+
+ $this->loadPhrases(
+ array(
+ 'global',
+ 'ui',
+ 'oehbeitrag'
+ )
+ );
}
public function index()
diff --git a/application/controllers/system/issues/Issues.php b/application/controllers/system/issues/Issues.php
index f942b50d9..e9764fb63 100644
--- a/application/controllers/system/issues/Issues.php
+++ b/application/controllers/system/issues/Issues.php
@@ -23,18 +23,21 @@ class Issues extends Auth_Controller
$this->load->library('PermissionLib');
$this->load->library('WidgetLib');
+ // Load models
+ $this->load->model('person/Benutzerfunktion_model', 'BenutzerfunktionModel');
+ $this->load->model('organisation/Organisationseinheit_model', 'OrganisationseinheitModel');
+
$this->loadPhrases(
array(
'global',
'ui',
- 'filter'
+ 'filter',
+ 'lehre',
+ 'person',
+ 'fehlermonitoring'
)
);
- // Load models
- $this->load->model('person/Benutzerfunktion_model', 'BenutzerfunktionModel');
- $this->load->model('organisation/Organisationseinheit_model', 'OrganisationseinheitModel');
-
$this->_setAuthUID(); // sets property uid
}
diff --git a/application/views/codex/oehbeitrag.php b/application/views/codex/oehbeitrag.php
index 7cfb18fe8..8a697129e 100644
--- a/application/views/codex/oehbeitrag.php
+++ b/application/views/codex/oehbeitrag.php
@@ -12,6 +12,14 @@ $this->load->view(
'dialoglib' => true,
'ajaxlib' => true,
'navigationwidget' => true,
+ 'phrases' => array(
+ 'person' => array('vorname', 'nachname'),
+ 'global' => array('unbeschraenkt'),
+ 'ui' => array('bearbeiten', 'loeschen', 'speichern', 'entfernen'),
+ 'oehbeitrag' => array('oehbeitraegeFestgelegt', 'fehlerHolenOehbeitraege', 'fehlerHolenSemester',
+ 'fehlerHinzufuegenOehbeitrag', 'fehlerAktualisierenOehbeitrag',
+ 'fehlerLoeschenOehbeitrag')
+ ),
'customCSSs' => array('public/css/sbadmin2/tablesort_bootstrap.css', 'public/css/codex/oehbeitrag.css'),
'customJSs' => array('public/js/tablesort/tablesort.js', 'public/js/codex/oehbeitrag.js')
)
@@ -28,23 +36,23 @@ $this->load->view(
-
Neuen Öhbeitrag hinzufügen
+
p->t('oehbeitrag', 'oehbeitragHinzufuegen') ?>
- Gültig von
- Gültig bis
- Studierendenbetrag
- Versicherungsbetrag
- Aktion
+ p->t('global', 'gueltigVon')) ?>
+ p->t('global', 'gueltigBis')) ?>
+ p->t('oehbeitrag', 'studierendenbetrag')) ?>
+ p->t('oehbeitrag', 'versicherungsbetrag')) ?>
+ p->t('ui', 'aktion')) ?>
diff --git a/application/views/system/issues/issues.php b/application/views/system/issues/issues.php
index ebe92012d..9812528d5 100644
--- a/application/views/system/issues/issues.php
+++ b/application/views/system/issues/issues.php
@@ -15,10 +15,11 @@ $this->load->view(
'navigationwidget' => true,
'dialoglib' => true,
'phrases' => array(
- 'ui' => array('bitteEintragWaehlen')
+ 'ui',
+ 'fehlermonitoring'
),
'customCSSs' => array('public/css/issues/issuesDataset.css', 'public/css/sbadmin2/tablesort_bootstrap.css'),
- 'customJSs' => array('public/js/issues/issuesDataset.js', 'public/js/bootstrapper.js')
+ 'customJSs' => array('public/js/issues/issuesDataset.js', 'public/js/bootstrapper.js'),
)
);
?>
@@ -33,7 +34,7 @@ $this->load->view(
diff --git a/public/js/codex/oehbeitrag.js b/public/js/codex/oehbeitrag.js
index 77a98a27b..1b2b68d9c 100644
--- a/public/js/codex/oehbeitrag.js
+++ b/public/js/codex/oehbeitrag.js
@@ -30,8 +30,8 @@ $(document).ready(function ()
newRowHtml += "";
newRowHtml += " "+
" "+
- "Speichern " +
- " Entfernen "+
+ ""+FHC_PhrasesLib.t('ui', 'speichern')+" " +
+ " "+FHC_PhrasesLib.t('ui', 'entfernen')+" "+
"";
$("#oehbeitraegeTbl tbody").prepend(newRowHtml);
@@ -67,7 +67,7 @@ $(document).ready(function ()
Oehbeitrag.newBeitragId++;
}
else
- FHC_DialogLib.alertInfo("ÖH-Beiträge für alle Studiensemester festgelegt");
+ FHC_DialogLib.alertInfo(FHC_PhrasesLib.t('oehbeitrag', 'oehbeitraegeFestgelegt'));
}
Oehbeitrag.getValidStudiensemester(callback);
@@ -106,7 +106,7 @@ var Oehbeitrag = {
Oehbeitrag._formatDateToGerman(oehbeitrag.von_datum) + '/' + oehbeitrag.von_studiensemester_kurzbz +
' '+
'' +
- '' + (oehbeitrag.bis_studiensemester_kurzbz == null ? 'unbeschränkt' :
+ ' ' + (oehbeitrag.bis_studiensemester_kurzbz == null ? FHC_PhrasesLib.t('global', 'unbeschraenkt') :
Oehbeitrag._formatDateToGerman(oehbeitrag.bis_datum) + '/' + oehbeitrag.bis_studiensemester_kurzbz) +
' '+
' ' +
@@ -117,8 +117,8 @@ var Oehbeitrag = {
' '+
'' +
'' +
- 'Bearbeiten ' +
- ' Löschen ' +
+ ''+FHC_PhrasesLib.t('ui', 'bearbeiten')+' ' +
+ ' '+FHC_PhrasesLib.t('ui', 'loeschen')+' ' +
' ' +
'';
}
@@ -133,7 +133,7 @@ var Oehbeitrag = {
},
errorCallback: function()
{
- FHC_DialogLib.alertError('Fehler beim Holen der Öhbeiträge');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerHolenOehbeitraege'));
}
}
);
@@ -150,7 +150,7 @@ var Oehbeitrag = {
successCallback: callback,
errorCallback: function()
{
- FHC_DialogLib.alertError('Fehler beim Holen der Semester');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerHolenSemester'));
}
}
);
@@ -173,12 +173,12 @@ var Oehbeitrag = {
}
else
{
- FHC_DialogLib.alertError('Fehler beim Hinzufügen des Öhbeitrags');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerHinzufuegenOehbeitrag'));
}
},
errorCallback: function()
{
- FHC_DialogLib.alertError('Fehler beim Hinzufügen des Öhbeitrags');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerHinzufuegenOehbeitrag'));
}
}
);
@@ -205,12 +205,12 @@ var Oehbeitrag = {
}
else
{
- FHC_DialogLib.alertError('Fehler beim Aktualisieren des Öhbeitrags');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerAktualisierenOehbeitrag'));
}
},
errorCallback: function()
{
- FHC_DialogLib.alertError('Fehler beim Aktualisieren des Öhbeitrags');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerAktualisierenOehbeitrag'));
}
}
);
@@ -259,12 +259,12 @@ var Oehbeitrag = {
}
else
{
- FHC_DialogLib.alertError('Fehler beim Aktualisieren des Öhbeitrags');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerAktualisierenOehbeitrag'));
}
},
errorCallback: function()
{
- FHC_DialogLib.alertError('Fehler beim Aktualisieren des Öhbeitrags');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerAktualisierenOehbeitrag'));
}
}
);
@@ -283,12 +283,12 @@ var Oehbeitrag = {
}
else
{
- FHC_DialogLib.alertError('Fehler beim Löschen des Öhbeitrags');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerLoeschenOehbeitrag'));
}
},
errorCallback: function()
{
- FHC_DialogLib.alertError('Fehler beim Löschen des Öhbeitrags');
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t('oehbeitrag', 'fehlerLoeschenOehbeitrag'));
}
}
);
@@ -310,7 +310,7 @@ var Oehbeitrag = {
Oehbeitrag._makeFieldEditable(id, 'bis_studiensemester_kurzbz', 'semester');
Oehbeitrag._makeFieldEditable(id, 'studierendenbeitrag');
Oehbeitrag._makeFieldEditable(id, 'versicherung');
- $(this).after(" Speichern ");
+ $(this).after(" "+FHC_PhrasesLib.t('ui', 'speichern')+" ");
$(this).remove();
$("#delete_" + oehbeitrag_id).remove();
diff --git a/public/js/issues/issuesDataset.js b/public/js/issues/issuesDataset.js
index b102a3f96..ac3732844 100644
--- a/public/js/issues/issuesDataset.js
+++ b/public/js/issues/issuesDataset.js
@@ -11,21 +11,21 @@ var IssuesDataset = {
{
let auswahlStatus =
'' +
- '' +
- ' Behoben ' +
- ' in Bearbeitung ' +
- ' Neu ' +
- ' ' +
- '' +
- 'Status für Ausgewählte setzen ' +
- ' ' +
+ '' +
+ ''+FHC_PhrasesLib.t("fehlermonitoring", "behoben")+' ' +
+ ''+FHC_PhrasesLib.t("fehlermonitoring", "inBearbeitung")+' ' +
+ ''+FHC_PhrasesLib.t("ui", "neu")+' ' +
+ ' ' +
+ '' +
+ ''+FHC_PhrasesLib.t("fehlermonitoring", "statusFuerAusgewaehlteSetzen")+' ' +
+ ' ' +
'
';
let selectAllHtml =
'' +
- ' Alle ' +
+ ' '+FHC_PhrasesLib.t("ui", "alle")+' ' +
'' +
- ' Keinen ';
+ ' '+FHC_PhrasesLib.t("ui", "keinen")+' ';
let issuescount = 0;
@@ -42,7 +42,7 @@ var IssuesDataset = {
if (issuescount > 0)
{
- var countHtml = issuescount + " Fehler";
+ var countHtml = issuescount + " "+FHC_PhrasesLib.t("fehlermonitoring", "meldungen");
// Count Records after Filtering
$("#filterTableDataset").bind("filterEnd", function() {
@@ -86,10 +86,10 @@ var IssuesDataset = {
let issue_ids_sel = $("#filterTableDataset input:checked[name=issue_id\\[\\]]");
if(status_kurzbz.length <= 0)
- return FHC_DialogLib.alertInfo("Bitte wählen Sie den Status aus.");
+ return FHC_DialogLib.alertInfo(FHC_PhrasesLib.t("fehlermonitoring", "bitteStatusWaehlen"));
if(issue_ids_sel.length <= 0)
- return FHC_DialogLib.alertInfo("Bitte wählen Sie die Fehler aus.");
+ return FHC_DialogLib.alertInfo(FHC_PhrasesLib.t("fehlermonitoring", "bitteFehlerWaehlen"));
let issue_ids = [];
@@ -107,17 +107,20 @@ var IssuesDataset = {
{
successCallback: function(data, textStatus, jqXHR) {
if (FHC_AjaxClient.isError(data))
- FHC_DialogLib.alertError("Fehler beim Status Ändern: " + FHC_AjaxClient.getError(data));
+ FHC_DialogLib.alertError(
+ FHC_PhrasesLib.t("fehlermonitoring", "statusAendernFehler") + ": "
+ + FHC_AjaxClient.getError(data)
+ );
else if (FHC_AjaxClient.hasData(data))
{
FHC_FilterWidget.reloadDataset();
FHC_DialogLib.alertSuccess(FHC_AjaxClient.getData(data));
}
else
- FHC_DialogLib.alertError("Unbekannter Fehler beim Status Ändern");
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t("fehlermonitoring", "statusAendernUnbekannterFehler"));
},
errorCallback: function(jqXHR, textStatus, errorThrown) {
- FHC_DialogLib.alertError("Fehler beim Status Ändern: " + textStatus);
+ FHC_DialogLib.alertError(FHC_PhrasesLib.t("fehlermonitoring", "statusAendernFehler") + ": " + textStatus);
}
}
);
diff --git a/system/dbupdate_3.3.php b/system/dbupdate_3.3.php
index 755abc627..386816a08 100644
--- a/system/dbupdate_3.3.php
+++ b/system/dbupdate_3.3.php
@@ -5278,14 +5278,14 @@ if(!$result = @$db->db_query("SELECT 1 FROM system.tbl_issue_status LIMIT 1;"))
else
echo ' system.tbl_issue_status: Tabelle hinzugefuegt';
- // GRANT SELECT ON TABLE bis.tbl_bisstandort TO web;
+ // GRANT SELECT ON TABLE system.tbl_issue_status TO web;
$qry = 'GRANT SELECT ON TABLE system.tbl_issue_status TO web;';
if (!$db->db_query($qry))
echo 'system.tbl_issue_status '.$db->db_last_error().' ';
else
echo ' Granted privileges to web on system.tbl_issue_status';
- // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE bis.tbl_issue_status TO vilesci;
+ // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_issue_status TO vilesci;
$qry = 'GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_issue_status TO vilesci;';
if (!$db->db_query($qry))
echo 'system.tbl_issue_status '.$db->db_last_error().' ';
@@ -5314,14 +5314,14 @@ if(!$result = @$db->db_query("SELECT 1 FROM system.tbl_fehlertyp LIMIT 1;"))
else
echo ' system.tbl_fehlertyp: Tabelle hinzugefuegt';
- // GRANT SELECT ON TABLE bis.tbl_bisstandort TO web;
+ // GRANT SELECT ON TABLE system.tbl_fehlertyp TO web;
$qry = 'GRANT SELECT ON TABLE system.tbl_fehlertyp TO web;';
if (!$db->db_query($qry))
echo 'system.tbl_fehlertyp '.$db->db_last_error().' ';
else
echo ' Granted privileges to web on system.tbl_fehlertyp';
- // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE bis.tbl_bisstandort TO vilesci;
+ // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_fehlertyp TO vilesci;
$qry = 'GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_fehlertyp TO vilesci;';
if (!$db->db_query($qry))
echo 'system.tbl_fehlertyp '.$db->db_last_error().' ';
@@ -5364,14 +5364,14 @@ if(!$result = @$db->db_query("SELECT 1 FROM system.tbl_fehler LIMIT 1;"))
else
echo ' system.tbl_fehler: Tabelle hinzugefuegt';
- // GRANT SELECT ON TABLE bis.tbl_issue TO web;
+ // GRANT SELECT ON TABLE system.tbl_fehler TO web;
$qry = 'GRANT SELECT, UPDATE ON TABLE system.tbl_fehler TO web;';
if (!$db->db_query($qry))
echo 'system.tbl_fehler '.$db->db_last_error().' ';
else
echo ' Granted privileges to web on system.tbl_fehler';
- // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE bis.tbl_issue TO vilesci;
+ // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_fehler TO vilesci;
$qry = 'GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_fehler TO vilesci;';
if (!$db->db_query($qry))
echo 'system.tbl_fehler '.$db->db_last_error().' ';
@@ -5422,14 +5422,14 @@ if(!$result = @$db->db_query("SELECT 1 FROM system.tbl_fehler_zustaendigkeiten L
else
echo ' system.tbl_fehler_zustaendigkeiten: Tabelle hinzugefuegt';
- // GRANT SELECT ON TABLE bis.tbl_issue TO web;
+ // GRANT SELECT ON TABLE system.tbl_fehler_zustaendigkeiten TO web;
$qry = 'GRANT SELECT ON TABLE system.tbl_fehler_zustaendigkeiten TO web;';
if (!$db->db_query($qry))
echo 'system.tbl_fehler_zustaendigkeiten '.$db->db_last_error().' ';
else
echo ' Granted privileges to web on system.tbl_fehler_zustaendigkeiten';
- // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE bis.tbl_issue TO vilesci;
+ // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_fehler_zustaendigkeiten TO vilesci;
$qry = 'GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_fehler_zustaendigkeiten TO vilesci;';
if (!$db->db_query($qry))
echo 'system.tbl_fehler_zustaendigkeiten '.$db->db_last_error().' ';
@@ -5500,14 +5500,14 @@ if(!$result = @$db->db_query("SELECT 1 FROM system.tbl_issue LIMIT 1;"))
else
echo ' system.tbl_issue: Tabelle hinzugefuegt';
- // GRANT SELECT ON TABLE bis.tbl_issue TO web;
+ // GRANT SELECT ON TABLE system.tbl_issue TO web;
$qry = 'GRANT SELECT, UPDATE ON TABLE system.tbl_issue TO web;';
if (!$db->db_query($qry))
echo 'system.tbl_issue '.$db->db_last_error().' ';
else
echo ' Granted privileges to web on system.tbl_issue';
- // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE bis.tbl_issue TO vilesci;
+ // GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_issue TO vilesci;
$qry = 'GRANT SELECT, UPDATE, INSERT, DELETE ON TABLE system.tbl_issue TO vilesci;';
if (!$db->db_query($qry))
echo 'system.tbl_issue '.$db->db_last_error().' ';
diff --git a/system/filtersupdate.php b/system/filtersupdate.php
index 2998640ed..78e2bb227 100644
--- a/system/filtersupdate.php
+++ b/system/filtersupdate.php
@@ -866,7 +866,7 @@ $filters = array(
'default_filter' => true,
'filter' => '
{
- "name": "Alle offenen Fehler",
+ "name": "Alle offenen Fehler, hauptzuständig",
"columns": [
{"name": "Datum"},
{"name": "Inhalt"},
@@ -880,6 +880,11 @@ $filters = array(
"name": "Fehlerstatus",
"operation": "ncontains",
"condition": "behoben"
+ },
+ {
+ "name": "Hauptzuständig",
+ "operation": "contains",
+ "condition": "Ja"
}
]
}
diff --git a/system/phrasesupdate.php b/system/phrasesupdate.php
index 7ebdaab83..b3518c79f 100644
--- a/system/phrasesupdate.php
+++ b/system/phrasesupdate.php
@@ -12933,6 +12933,748 @@ array(
)
)
),
+ //******************* ÖH-Beitragsverwaltung
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'oehbeitragsVerwaltung',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "ÖH-Beitragsverwaltung",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Student Union Fee Management",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'oehbeitragHinzufuegen',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Neuen ÖH-Beitrag hinzufügen",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Add new student union fee",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'global',
+ 'phrase' => 'gueltigVon',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "gültig von",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "valid from",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'global',
+ 'phrase' => 'gueltigBis',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "gültig bis",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "valid to",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'studierendenbetrag',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "studierendenbetrag",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "student amount",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'versicherungsbetrag',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "versicherungsbetrag",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "insurance amount",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'ui',
+ 'phrase' => 'aktion',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Aktion",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "action",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'ui',
+ 'phrase' => 'bearbeiten',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Bearbeiten",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Edit",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'global',
+ 'phrase' => 'unbeschraenkt',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "unbeschränkt",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "unlimited",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'oehbeitraegeFestgelegt',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "ÖH-Beiträge für alle Studiensemester festgelegt",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "show menu",
+ 'description' => 'Student union fees set for all semesters',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'fehlerHolenOehbeitraege',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehler beim Holen der Öhbeiträge",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error when getting student union fees",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'fehlerHolenSemester',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehler beim Holen der Semester",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error when getting semester",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'fehlerHinzufuegenOehbeitrag',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehler beim Hinzufügen des ÖH-Beitrags",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error when adding student union fee",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'fehlerAktualisierenOehbeitrag',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehler beim Aktualisieren des ÖH-Beitrags",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error when updating student union fee",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'oehbeitrag',
+ 'phrase' => 'fehlerLoeschenOehbeitrag',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehler beim Löschen des ÖH-Beitrags",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error when deleting student union fee",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ //******************* Issue/Fehler Monitoring
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'fehlerMonitoring',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehler Monitoring",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error Monitoring",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'ui',
+ 'phrase' => 'keinen',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Keinen",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "None",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'statusFuerAusgewaehlteSetzen',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Status für Ausgewählte setzen",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Set state for selected",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'meldungen',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Meldungen",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "messages",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'behoben',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Behoben",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Resolved",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'inBearbeitung',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "In Bearbeitung",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "In progress",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'inhalt',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Inhalt",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Content",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'inhaltExtern',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Inhalt extern",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "External content",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'fehlerstatus',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehlerstatus",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error state",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'fehlercode',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehlercode",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error code",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'fehlercodeExtern',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehlercode extern",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "External error code",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'fehlertyp',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehlertyp",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error type",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'verarbeitetVon',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Verarbeitet von",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Processed by",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'verarbeitetAm',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Verarbeitet am",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Processed on",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'global',
+ 'phrase' => 'applikation',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Applikation",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "application",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'fehlertypcode',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehlertypcode",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error type code",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'statuscode',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Statuscode",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "State code",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'hauptzustaendig',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Hauptzuständig",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Main responsibility",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'bitteStatusWaehlen',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Bitte wählen Sie den Status aus.",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Please select the state.",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'bitteFehlerWaehlen',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Bitte wählen Sie die Fehler aus.",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Please select the errors.",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'statusAendernFehler',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Fehler beim Status Ändern",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Error when changing state",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ ),
+ array(
+ 'app' => 'core',
+ 'category' => 'fehlermonitoring',
+ 'phrase' => 'statusAendernUnbekannterFehler',
+ 'insertvon' => 'system',
+ 'phrases' => array(
+ array(
+ 'sprache' => 'German',
+ 'text' => "Unbekannter Fehler beim Status Ändern",
+ 'description' => '',
+ 'insertvon' => 'system'
+ ),
+ array(
+ 'sprache' => 'English',
+ 'text' => "Unknown error when changing state",
+ 'description' => '',
+ 'insertvon' => 'system'
+ )
+ )
+ )
);
diff --git a/application/views/system/issues/issuesData.php b/application/views/system/issues/issuesData.php
index 1f0bf12b0..c9a1d3828 100644
--- a/application/views/system/issues/issuesData.php
+++ b/application/views/system/issues/issuesData.php
@@ -4,40 +4,64 @@ $PERSON_ID = getAuthPersonId();
$ALL_FUNKTIONEN_OE_KURZBZ = "('" . implode("','", array_keys($all_funktionen_oe_kurzbz)) . "')";
$ALL_OE_KURZBZ_BERECHTIGT = "('" . implode("','", $all_oe_kurzbz_berechtigt) . "')";
$RELEVANT_PRESTUDENT_STATUS = "('Aufgenommener', 'Student', 'Incoming', 'Diplomand', 'Abbrecher', 'Unterbrecher', 'Absolvent')";
+$LANGUAGE_INDEX = getUserLanguage() == 'German' ? '1' : '2';
-// get issues for the oes of the uid or for the persons (students, oe-zuordnung) of the oes
-$query = "SELECT issue_id, fehlercode AS \"Fehlercode\", iss.fehlercode_extern AS \"Fehlercode extern\", datum AS \"Datum\",
+// get issues for the oes of the logged user or for the persons (students, oe-zuordnung) of the oes
+$query = "WITH zustaendigkeiten AS (
+ SELECT fehlercode,
+ CASE
+ WHEN zst.person_id = ".$PERSON_ID;
+
+ if (!isEmptyArray($all_funktionen_oe_kurzbz))
+ {
+ $query .= " OR (zst.oe_kurzbz IN $ALL_FUNKTIONEN_OE_KURZBZ AND zst.funktion_kurzbz IS NULL) /* if oe is specified in fehler_zustaendigkeiten */";
+
+ // check for each oe for each function if zustaendig
+ foreach ($all_funktionen_oe_kurzbz as $oe_kurzbz => $funktionen_kurzbz)
+ {
+ foreach ($funktionen_kurzbz as $funktion_kurzbz)
+ {
+ $query .= " OR (zst.oe_kurzbz = '$oe_kurzbz' AND zst.funktion_kurzbz = '$funktion_kurzbz')";
+ }
+ }
+ }
+
+ $query .= " THEN TRUE
+ ELSE FALSE
+ END AS \"zustaendig\"
+ FROM system.tbl_fehler_zustaendigkeiten zst
+ )";
+
+$query .= "SELECT issue_id, fehlercode AS \"Fehlercode\", iss.fehlercode_extern AS \"Fehlercode extern\", datum AS \"Datum\",
inhalt AS \"Inhalt\", inhalt_extern AS \"Inhalt extern\", iss.person_id AS \"PersonId\", iss.oe_kurzbz AS \"OE\",
- ftyp.bezeichnung_mehrsprachig[1] AS \"Fehlertyp\", stat.bezeichnung_mehrsprachig[1] AS \"Fehlerstatus\",
+ ftyp.bezeichnung_mehrsprachig[".$LANGUAGE_INDEX."] AS \"Fehlertyp\", stat.bezeichnung_mehrsprachig[".$LANGUAGE_INDEX."] AS \"Fehlerstatus\",
verarbeitetvon AS \"Verarbeitet von\",verarbeitetamum AS \"Verarbeitet am\", fr.app AS \"Applikation\",
- fr.fehlertyp_kurzbz as \"Fehlertypcode\", iss.status_kurzbz AS \"Statuscode\",
- pers.vorname AS \"Vorname\", pers.nachname AS \"Nachname\"
+ fr.fehlertyp_kurzbz AS \"Fehlertypcode\", iss.status_kurzbz AS \"Statuscode\",
+ pers.vorname AS \"Vorname\", pers.nachname AS \"Nachname\",
+ CASE
+ WHEN
+ EXISTS(SELECT 1
+ FROM zustaendigkeiten
+ WHERE fehlercode = iss.fehlercode
+ AND zustaendig = TRUE) /* If Zuständigkeit is defined for the oe/person, zustaendig. */
+ THEN 'Ja'
+ WHEN
+ EXISTS(SELECT 1
+ FROM zustaendigkeiten
+ WHERE fehlercode = iss.fehlercode
+ AND zustaendig = FALSE) /* If Zuständigkeit is defined for different oe/person, not zustaendig. */
+ THEN 'Nein'
+ ELSE 'Ja' /* If no Zuständigkeit defined, zustaendig by default. */
+ END AS \"Hauptzuständig\"
FROM system.tbl_issue iss
JOIN system.tbl_fehler fr USING (fehlercode)
JOIN system.tbl_fehlertyp ftyp USING (fehlertyp_kurzbz)
JOIN system.tbl_issue_status stat USING (status_kurzbz)
LEFT JOIN public.tbl_person pers ON iss.person_id = pers.person_id
- WHERE EXISTS (
- SELECT 1 FROM system.tbl_fehler_zustaendigkeiten zst
+ WHERE EXISTS ( /* if oe or person is specified in fehler_zustaendigkeiten */
+ SELECT 1 FROM zustaendigkeiten
WHERE fehlercode = iss.fehlercode
- AND (
- person_id = ".$PERSON_ID." /* person_id in fehler_zustaendigkeit for individual persons */";
-
-if (!isEmptyArray($all_funktionen_oe_kurzbz))
-{
- $query .= " OR (zst.oe_kurzbz IN $ALL_FUNKTIONEN_OE_KURZBZ AND zst.funktion_kurzbz IS NULL) /* if oe is specified in fehler_zustaendigkeiten */";
-
- // check for each oe for each function if zustaendig
- foreach ($all_funktionen_oe_kurzbz as $oe_kurzbz => $funktionen_kurzbz)
- {
- foreach ($funktionen_kurzbz as $funktion_kurzbz)
- {
- $query .= " OR (zst.oe_kurzbz = '$oe_kurzbz' AND zst.funktion_kurzbz = '$funktion_kurzbz')";
- }
- }
-}
-
-$query .= "))"; // close AND of exists, and exists
+ AND zustaendig = TRUE)";
// show issue if it is assigend to oe of logged in user or to student of oe of logged in user
if (!isEmptyArray($all_oe_kurzbz_berechtigt))
@@ -92,22 +116,23 @@ $filterWidgetArray = array(
'checkboxes' => 'issue_id',
'columnsAliases' => array(
'ID',
- 'Fehlercode',
- 'Fehlercode extern',
- 'Datum',
- 'Inhalt',
- 'Inhalt extern',
+ ucfirst($this->p->t('fehlermonitoring', 'fehlercode')),
+ ucfirst($this->p->t('fehlermonitoring', 'fehlercodeExtern')),
+ ucfirst($this->p->t('global', 'datum')),
+ ucfirst($this->p->t('fehlermonitoring', 'inhalt')),
+ ucfirst($this->p->t('fehlermonitoring', 'inhaltExtern')),
'PersonId',
- 'OE',
- 'Fehlertyp',
- 'Fehlerstatus',
- 'Verarbeitet von',
- 'Verarbeitet am',
- 'Applikation',
- 'Fehlertypcode',
- 'Statuscode',
- 'Vorname',
- 'Nachname'
+ ucfirst($this->p->t('lehre', 'organisationseinheit')),
+ ucfirst($this->p->t('fehlermonitoring', 'fehlertyp')),
+ ucfirst($this->p->t('fehlermonitoring', 'fehlerstatus')),
+ ucfirst($this->p->t('fehlermonitoring', 'verarbeitetVon')),
+ ucfirst($this->p->t('fehlermonitoring', 'verarbeitetAm')),
+ ucfirst($this->p->t('global', 'applikation')),
+ ucfirst($this->p->t('fehlermonitoring', 'fehlertypcode')),
+ ucfirst($this->p->t('fehlermonitoring', 'statuscode')),
+ ucfirst($this->p->t('person', 'vorname')),
+ ucfirst($this->p->t('person', 'nachname')),
+ ucfirst($this->p->t('fehlermonitoring', 'hauptzustaendig'))
),
'formatRow' => function($datasetRaw) {